/**
 * Add to cart popup object.
 *
 * @since 1.0.0
 */
var wcAtcpCartPopup = {
	popup: jQuery( '.wc-atcp' ),
	loader: jQuery( '.wc-atcp-loader' ),

	open: function() {
		this.popup.addClass( 'wc-atcp--open' );
		jQuery( 'body' ).addClass( 'wc-atcp-no-scrolling' );
	},

	close: function() {
		this.popup.removeClass( 'wc-atcp--open' );
		jQuery( 'body' ).removeClass( 'wc-atcp-no-scrolling' );
	},

	isOpen: function() {
		return this.popup.hasClass( 'wc-atcp--open' ) ? true : false;
	},

	isLoader: function() {
		return this.popup.hasClass( 'wc-atcp-has-loader' ) ? true : false;
	},

	showLoader: function() {
		if ( this.isLoader() ) {
			this.loader.addClass( 'wc-atcp-loader--show' );
		} else {
			this.popup.addClass( 'wc-atcp-has-loader' );
			this.showLoader();
		}
	},

	hideLoader: function() {
		if ( this.isLoader() ) {
			this.loader.removeClass( 'wc-atcp-loader--show' );
		}
	}
};

( function( $ ) {
	'use strict';

	var ajaxRequest;

	/**
	 * Cart trigger.
	 *
	 * @since 1.0.0
	 */
	function cartPopupTrigger() {
		if ( wcAtcpCartPopup.isOpen() ) {
			wcAtcpCartPopup.close();
		} else {
			wcAtcpCartPopup.open();
		}
	}

	$( document ).ready( function() {

		/**
		 * Cart popup trigger using data attribute.
		 *
		 * @since 1.0.0
		 */
		$( '[data-atcp-cart-popup-trigger]' ).on( 'click', function() {
			cartPopupTrigger();
		} );

		/**
		 * Close cart popup when ESC key pressed.
		 *
		 * @since 1.0.0
		 */
		$( document ).on( 'keydown', function( event ) {
			if ( 'Escape' === event.key ) {
				wcAtcpCartPopup.close();
			}
		} );

		/**
		 * Close cart popup when clicked on overlay.
		 *
		 * @since 1.0.0
		 */
		$( '.wc-atcp' ).on( 'click', function( event ) {
			if ( event.target.className && typeof event.target.className.includes !== 'undefined' && event.target.className.includes( 'wc-atcp--open' ) ) {
				cartPopupTrigger();
			}
		} );

		/**
		 * Added to cart popup handel.
		 *
		 * @since 1.0.0
		 */
		$( document.body ).on( 'added_to_cart', function( fragments, cart_hash ) {
			// Fix: Elementor Pro: Popup display when click on update button.
			if ( cart_hash.stop_reload || ( cart_hash.e_manually_triggered && true === cart_hash.e_manually_triggered ) ) {
				return;
			}

			wcAtcpCartPopup.open();

			$( '.wc-atcp-popup__body' ).scrollTop(0);

			/**
			 * Triger when product added to cart.
			 *
			 * @since 1.0.0
			 */
			$( document.body ).trigger( 'atcp_added_to_cart' );
		} );

		/**
		 * Handel product quantity increment button.
		 */
		jQuery( document ).on( 'click', '.wc-atcp-product__qty-plus', function() {
			var spinner		= jQuery( this ).closest( '.wc-atcp-product__qty' ),
				input		= spinner.find( 'input' ),
				max			= input.attr( 'max' ) || 999,
				oldValue 	= parseFloat( input.val() ),
				newVal		= '';

			if ( oldValue >= max ) {
				newVal = oldValue;
			} else {
				newVal = oldValue + 1;
			}

			/**
			 * Triger when product quantity increase.
			 *
			 * @since 1.0.0
			 */
			$( document.body ).trigger( 'atcp_product_quantity_increase' );

			spinner.find( 'input' ).val( newVal );
			spinner.find( 'input' ).trigger( 'change' );
		} );

		/**
		 * Handel product quantity decrement button.
		 */
		jQuery( document ).on( 'click', '.wc-atcp-product__qty-minus', function() {
			var spinner		= jQuery( this ).closest( '.wc-atcp-product__qty' ),
				input		= spinner.find( 'input' ),
				min			= input.attr( 'min' ) || 0,
				oldValue	= parseFloat( input.val() ),
				newVal 		= '';

			if ( oldValue <= min ) {
				newVal = oldValue;
			} else {
				newVal = oldValue - 1;
			}

			/**
			 * Triger when product quantity decrease.
			 *
			 * @since 1.0.0
			 */
			$( document.body ).trigger( 'atcp_product_quantity_decrease' );

			spinner.find( 'input' ).val( newVal );
			spinner.find( 'input' ).trigger( 'change' );
		} );

		/**
		 * Single page add to cart popup.
		 *
		 * @since 1.0.0
		 */
		$( document ).on( 'submit', 'form.cart', function( e ){
			var form      = $( this );
			var atc_btn   = form.find( 'button[type="submit"]');
			var form_data = form.serializeArray();

			// if button as name add-to-cart get it and add to form
			if ( atc_btn.attr( 'name' ) && atc_btn.attr( 'name' ) === 'add-to-cart' && atc_btn.attr( 'value' ) ) {
				form_data.push( { name: 'add-to-cart', value: atc_btn.attr( 'value' ) } );
			}

			var is_valid = false;

			$.each( form_data, function( index, data ){
				if( data.name === 'add-to-cart' ){
					is_valid = true;
					return false;
				}
			} );

			if ( is_valid ) {
				e.preventDefault();
			} else {
				return;
			}

			form_data.push( { name: 'action', value: 'atcp_added_to_cart_popup' } );
			form_data.push( { name: 'security_token', value: wcAtcpObject.security_token } );

			add_to_cart( atc_btn, form_data, form ); // Ajax add to cart
		} );

		/**
		 * Add to cart function.
		 *
		 * @since 1.0.0
		 */
		function add_to_cart( atc_btn, form_data, form ) {

			// Trigger event.
			$( document.body ).trigger( 'adding_to_cart', [ atc_btn, form_data ] );

			$.ajax( {
				url: wcAtcpObject.wc_ajax_url.toString().replace( '%%endpoint%%', 'atcp_added_to_cart_popup' ),
				type: 'POST',
				data: $.param( form_data ),
				beforeSend: function() {
					// Block form.
					form.block( { message: null, overlayCSS: { background: '#fff', opacity: 0.6 } } );
				},
				complete: function() {
					// Unlock form.
					form.unblock();
				},
				success: function( response ) {
					// If any WooCommerce error.
					if ( response.errors ) {
						var $ajaxContainer = $( '#wc-atcp-ajax' );

						$ajaxContainer.empty();

						$( response.errors ).each( function() {
							$ajaxContainer.append( '<div class="wc-atcp-popup-errors woocommerce-error">' + this.notice + '</div>' );
						} );

						wcAtcpCartPopup.open();
					} else if ( response.fragments ) {

						// Trigger event so themes can refresh other areas.
						$( document.body ).trigger( 'added_to_cart', [ response.fragments, response.cart_hash, atc_btn ] );
					}
				}
			} );
		}

		/**
		 * Update flying cart by updating product quantity.
		 */
		jQuery( document ).on( 'change', '.wc-atcp-product__qty input', function() {
			var cartItemKey = jQuery( this ).attr( 'name' );
			var quantity    = jQuery( this ).val();

			ajaxRequest = jQuery.ajax( {
				url: wcAtcpObject.wc_ajax_url.toString().replace( '%%endpoint%%', 'atcp_update_product_quantity' ),
				type: 'post',
				dataType: 'json',
				data: {
					'cart_item_key': cartItemKey,
					'quantity': quantity,
					'security_token': wcAtcpObject.security_token
				},
				beforeSend : function()    {
					if ( null != ajaxRequest ) {
						ajaxRequest.abort();
					}
				},
				success: function( response ) {
					if ( ! response ) {
						return;
					}

					// Trigger event so themes can refresh other areas
					jQuery( document.body ).trigger( 'added_to_cart', [ response.fragments, response.cart_hash ] );
				}
			} );
		} );

		/**
		 * Vibration handler.
		 *
		 * @since 1.0.0
		 */
		$( document.body ).on( 'atcp_added_to_cart atcp_product_quantity_increase atcp_product_quantity_decrease', function() {
			if ( ! wcAtcpObject.is_vibration_on ) {
				return;
			}

			var vibration = navigator.vibrate;

			if ( vibration ) {
				navigator.vibrate( [100] );
			}
		} );

		/**
		 * Auto hide popup.
		 *
		 * @since 1.0.5
		 */
		$( document.body ).on( 'atcp_added_to_cart', function() {
			if ( wcAtcpObject.is_auto_hide ) {
				var AutoHideTime = wcAtcpObject.auto_hide_time || 5;

				setTimeout( function() {
					wcAtcpCartPopup.close();
				}, Number( AutoHideTime ) * 1000 );
			}
		} );

		/**
		 * Show loader.
		 *
		 * @since 1.3.0
		 */
		$( document.body ).on( 'atcp_product_quantity_increase atcp_product_quantity_decrease', function() {
			if ( wcAtcpCartPopup.isLoader() ) {
				wcAtcpCartPopup.showLoader();
			}
		} );

		/**
		 * Hide loader.
		 *
		 * @since 1.3.0
		 */
		$( document.body ).on( 'atcp_added_to_cart', function() {
			if ( wcAtcpCartPopup.isLoader() ) {
				wcAtcpCartPopup.hideLoader();
			}
		} );


	} ); // Doc.ready end.

} )( jQuery );
