<?php
/**
 * Functions.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

if ( ! function_exists( 'atpc_is_hide_on_current_page' ) ) {

	/**
	 * Check whether popup is hidden on the current page or not.
	 *
	 * @since 1.2.0
	 *
	 * @return bool default false. true, if hidden.
	 */
	function atpc_is_hide_on_current_page() {
		$hidden = false;

		// If yes, then hide popup on single product page.
		if ( is_product() && 'yes' === get_option( 'atcp_hide_on_product_page' ) ) {
			$hidden = true;
		}

		// If yes, then hide popup on the product archive but product page.
		if ( is_shop() && 'yes' === get_option( 'atcp_hide_on_product_archive' ) ) {
			$hidden = true;
		}

		// If yes, then hide popup on all pages but not on product and shop page.
		if ( ! is_shop() && ! is_product() && 'yes' === get_option( 'atcp_hide_on_all_other_pages' ) ) {
			$hidden = true;
		}

		return apply_filters( 'atcp_is_hide_on_current_page', $hidden, get_the_ID() );
	}
}

if ( ! function_exists( 'atcp_get_template' ) ) {

	/**
	 * Get template.
	 *
	 * @since 1.0.0
	 *
	 * @param string $template_name Template name.
	 * @param array  $args Arguments pass to template.
	 *
	 * @return string
	 */
	function atcp_get_template( $template_name, $args = array() ) {
		return wc_get_template( $template_name, $args, '', ATCP_PLUGIN_PATH . 'templates/' );
	}
}

if ( ! function_exists( 'atcp_woocommerce_quantity_input' ) ) {

	/**
	 * Output the quantity input for add to cart forms.
	 *
	 * @since 1.0.7
	 *
	 * @param  array           $args    Args for the input.
	 * @param  WC_Product|null $product WooCommerce product object.
	 * @param  boolean         $echo    Whether to return or echo|string.
	 */
	function atcp_woocommerce_quantity_input( $args = array(), $product = null, $echo = true ) {
		if ( is_null( $product ) ) {
			$product = $GLOBALS['product'];
		}

		$defaults = array(
			'input_name'  => 'quantity',
			'input_value' => '1',
			'max_value'   => apply_filters( 'woocommerce_quantity_input_max', -1, $product ),
			'min_value'   => apply_filters( 'woocommerce_quantity_input_min', 0, $product ),
			'step'        => apply_filters( 'woocommerce_quantity_input_step', 1, $product ),
			'pattern'     => apply_filters( 'woocommerce_quantity_input_pattern', has_filter( 'woocommerce_stock_amount', 'intval' ) ? '[0-9]*' : '' ),
			'inputmode'   => apply_filters( 'woocommerce_quantity_input_inputmode', has_filter( 'woocommerce_stock_amount', 'intval' ) ? 'numeric' : '' ),
		);

		$args = apply_filters( 'woocommerce_quantity_input_args', wp_parse_args( $args, $defaults ), $product );

		// Apply sanity to min/max args - min cannot be lower than 0.
		$args['min_value'] = max( $args['min_value'], 0 );
		$args['max_value'] = 0 < $args['max_value'] ? $args['max_value'] : '';

		// Max cannot be lower than min if defined.
		if ( '' !== $args['max_value'] && $args['max_value'] < $args['min_value'] ) {
			$args['max_value'] = $args['min_value'];
		}

		ob_start();

		if ( $args['max_value'] && $args['min_value'] === $args['max_value'] ) {
			?>
			<div class="hidden">
				<input type="hidden" class="qty" name="<?php echo esc_attr( $args['input_name'] ); ?>" value="<?php echo esc_attr( $args['min_value'] ); ?>" />
			</div>
			<?php
		} else {
			?>
			<div>
				<input
					type="number"
					step="<?php echo esc_attr( $args['step'] ); ?>"
					min="<?php echo esc_attr( $args['min_value'] ); ?>"
					max="<?php echo esc_attr( 0 < $args['max_value'] ? $args['max_value'] : '' ); ?>"
					name="<?php echo esc_attr( $args['input_name'] ); ?>"
					value="<?php echo esc_attr( $args['input_value'] ); ?>"
					size="4"
					inputmode="<?php echo esc_attr( $args['inputmode'] ); ?>" />
			</div>
			<?php
		}

		if ( $echo ) {
			echo ob_get_clean(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		} else {
			return ob_get_clean();
		}
	}
}

if ( ! function_exists( 'atcp_get_last_added_cart_key' ) ) {

	/**
	 * Get last added cart key.
	 *
	 * @since 1.3.1
	 * @return string|bool Cart key else, false.
	 */
	function atcp_get_last_added_cart_key() {
		return get_option( 'atcp_last_added_cart_key' );
	}
}

if ( ! function_exists( 'atcp_set_last_added_cart_key' ) ) {

	/**
	 * Set last added cart key.
	 *
	 * @since 1.3.1
	 * @param string $cart_key Cart key.
	 * @return void
	 */
	function atcp_set_last_added_cart_key( $cart_key ) {
		update_option( 'atcp_last_added_cart_key', $cart_key );
	}
}

if ( ! function_exists( 'atcp_delete_last_added_cart_key' ) ) {

	/**
	 * Delete last added cart key.
	 *
	 * @since 1.3.1
	 * @return void
	 */
	function atcp_delete_last_added_cart_key() {
		update_option( 'atcp_last_added_cart_key', '' );
	}
}

if ( ! function_exists( 'atcp_call_to_actions' ) ) {
	/**
	 * Get call to actions buttons.
	 *
	 * @since 1.3.1
	 *
	 * @return void
	 */
	function atcp_call_to_actions() {
		$atcp_cta          = array();
		$cart_page_url     = apply_filters( 'atcp_cart_page_url', get_option( 'atcp_cart_button_url' ) );
		$checkout_page_url = apply_filters( 'atcp_checkout_page_url', get_option( 'atcp_checkout_button_url' ) );

		if ( 'yes' !== get_option( 'atcp_continue_shopping_cart_button' ) ) {
			$atcp_cta['continue_shopping_button'] = array(
				'text'      => get_option( 'atcp_continue_shopping_button_text' ),
				'type'      => get_option( 'atcp_continue_shopping_button_type' ),
				'behaviour' => 'close_popup',
				'target'    => '_self',
			);
		}
		if ( 'yes' !== get_option( 'atcp_hide_cart_button' ) ) {
			$atcp_cta['cart_button'] = array(
				'text'      => get_option( 'atcp_cart_button_text' ),
				'type'      => get_option( 'atcp_cart_button_type' ),
				'behaviour' => 'link',
				'link'      => $cart_page_url,
				'target'    => '_self',
			);
		}
		if ( 'yes' !== get_option( 'atcp_hide_checkout_button' ) ) {
			$atcp_cta['checkout_button'] = array(
				'text'      => get_option( 'atcp_checkout_button_text' ),
				'type'      => get_option( 'atcp_checkout_button_type' ),
				'behaviour' => 'link',
				'link'      => $checkout_page_url,
				'target'    => '_self',
			);
		}

		/**
		 * Filter call to actions buttons.
		 *
		 * @since 1.3.1
		 *
		 * @param array $atcp_cta Call to actions array.
		 * @return array Call to actions filtered array.
		 */
		$atcp_cta = apply_filters( 'actp_call_to_actions', $atcp_cta );

		if ( isset( $atcp_cta ) && is_array( $atcp_cta ) ) {
			foreach ( $atcp_cta as $cta ) {
				$text      = isset( $cta['text'] ) ? sanitize_text_field( $cta['text'] ) : esc_html__( 'Button', 'woo-atcp' );
				$type      = isset( $cta['type'] ) ? sanitize_key( $cta['type'] ) : 'secondary';
				$behaviour = isset( $cta['behaviour'] ) ? sanitize_key( $cta['behaviour'] ) : 'link';

				if ( 'close_popup' === $behaviour ) {
					$link                         = 'javascript:;';
					$cta['attributes']['onclick'] = 'wcAtcpCartPopup.close();';
				} else {
					$link = isset( $cta['link'] ) ? esc_url_raw( $cta['link'] ) : '#';
				}

				$attributes = array();

				if ( isset( $cta['attributes'] ) && ! empty( $cta['attributes'] ) && is_array( $cta['attributes'] ) ) {
					foreach ( $cta['attributes'] as $attribute => $attribute_value ) {
						$attributes[] = esc_html( $attribute ) . '="' . esc_attr( $attribute_value ) . '"';
					}
				}

				$target = isset( $cta['target'] ) ? sanitize_key( $cta['target'] ) : '_self';

				echo wp_sprintf(
					'<a href="%3$s" class="wc-atcp-btn wc-atcp-btn--%2$s" target="%4$s" %5$s>%1$s</a>',
					esc_html( $text ),
					esc_attr( $type ),
					$link, // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					esc_attr( $target ),
					implode( ' ', $attributes ) // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				);
			}
		}
	}
}
