<?php
/**
 * Added to cart popup.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

if ( ! class_exists( 'ATCP_Cart_Popup' ) ) {

	/**
	 * Added to cart popup class.
	 *
	 * @since 1.0.0
	 */
	class ATCP_Cart_Popup {

		/**
		 * Class constructor.
		 *
		 * @since 1.0.0
		 */
		public function __construct() {
			add_action( 'init', array( $this, 'check_woocommerce_ajax_add_to_cart_availability' ) );
			add_action( 'wp_footer', array( $this, 'cart_popup' ) );
			add_filter( 'woocommerce_add_to_cart_fragments', array( $this, 'add_to_cart_fragments' ), 10, 1 );
			add_action( 'woocommerce_add_to_cart', array( $this, 'set_last_added_cart_item_key' ), 10, 6 );
			add_filter( 'atcp_classes', array( $this, 'atcp_classes' ), 20 );
			add_filter( 'pre_option_woocommerce_cart_redirect_after_add', array( $this, 'prevent_cart_redirect' ), 10, 1 );
		}

		/**
		 * Display cart popup.
		 *
		 * @since 1.0.0
		 *
		 * @return void
		 */
		public function cart_popup() {
			if ( atpc_is_hide_on_current_page() ) {
				return;
			}

			require_once ATCP_PLUGIN_PATH . 'templates/cart-popup.php';
		}

		/**
		 * Add to cart fragments.
		 *
		 * @since 1.0.0
		 *
		 * @param array $fragments  WooCommerce add to cart fragment.
		 * @return mixed
		 */
		public function add_to_cart_fragments( $fragments ) {

			// Get last cart item key.
			$cart_item_key = atcp_get_last_added_cart_key();

			if ( ! $cart_item_key ) {
				return $fragments;
			}

			/**
			 * Hook run before add to cart popup.
			 *
			 * @since 1.0.0
			 */
			do_action( 'atcp_before_add_to_cart_fragment', $cart_item_key );

			$cart = WC()->cart->get_cart();

			if ( ! isset( $cart[ $cart_item_key ] ) ) {
				return $fragments;
			}

			$cart_item = $cart[ $cart_item_key ];

			$_product          = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
			$product_id        = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
			$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
			$thumbnail         = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
			$product_name      = apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key ) . '&nbsp;';
			$product_price     = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
			$product_subtotal  = apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );

			$product_image = wp_get_attachment_image_url( $_product->get_image_id(), apply_filters( 'atcp_product_image_size', 'woocommerce_single' ) );
			$cart_total    = WC()->cart->total;

			ob_start();

			/**
			 * Filter cart item args.
			 *
			 * @since 1.3.2
			 *
			 * @param $cart_item_args Cart item args.
			 *
			 * @return array
			 */
			$template_args = apply_filters(
				'atcp_cart_item_args',
				array(
					'_product'          => $_product,
					'product_id'        => $product_id,
					'product_permalink' => $product_permalink,
					'thumbnail'         => $thumbnail,
					'product_name'      => $product_name,
					'product_price'     => $product_price,
					'product_subtotal'  => $product_subtotal,
					'product_image'     => $product_image,
					'cart_item_key'     => $cart_item_key,
					'cart_total'        => $cart_total,
					'cart_item'         => $cart_item,
				)
			);

			atcp_get_template( 'cart-popup-content.php', $template_args );

			$fragments['#wc-atcp-ajax'] = '<div id="wc-atcp-ajax">' . ob_get_clean() . '</div>';

			// Delete last added product key.
			atcp_delete_last_added_cart_key();

			return $fragments;
		}

		/**
		 * Store last added cart item key in option table.
		 *
		 * @since 1.0.0
		 *
		 * @param string $cart_item_key WooCommerce generated MD5 encrepted item key.
		 * @return void
		 */
		public function set_last_added_cart_item_key( $cart_item_key ) {
			atcp_set_last_added_cart_key( $cart_item_key );
		}

		/**
		 * Enable WooCommerce add to cart features if off by user.
		 *
		 * @since 1.0.0
		 *
		 * @return void
		 */
		public function check_woocommerce_ajax_add_to_cart_availability() {
			if ( 'no' === get_option( 'woocommerce_enable_ajax_add_to_cart' ) ) {
				update_option( 'woocommerce_enable_ajax_add_to_cart', 'yes' );
			}
		}

		/**
		 * Added to cart popup classes.
		 *
		 * @since 1.2.0
		 *
		 * @param array $classes CSS classes.
		 *
		 * @return array
		 */
		public function atcp_classes( $classes ) {
			$popup_design_mode = get_option( 'atcp_popup_design_mode' );

			if ( 'dark_mode' === $popup_design_mode ) {
				$classes[] = 'wc-atcp-dark-mode';
			} elseif ( 'glass_mode' === $popup_design_mode ) {
				$classes[] = 'wc-atcp-glass-mode';
			}

			if ( 'none' !== get_option( 'atcp_popup_loader' ) ) {
				$classes[] = 'wc-atcp-has-loader';
			}

			return $classes;
		}

		/**
		 * Prevent add to cart redirection.
		 *
		 * @since 1.3.7
		 *
		 * @param string $value Yes or no.
		 * @return string Filtered value.
		 */
		public function prevent_cart_redirect( $value ) {
			if ( ! is_admin() ) {
				return 'no';
			}

			return $value;
		}
	}

	global $atcp_cart_popup;

	$atcp_cart_popup = new ATCP_Cart_Popup();
}
