<?php
/**
 * Shortcodes.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

if ( ! class_exists( 'ATCP_Shortcodes' ) ) {
	/**
	 * Plugin shortcodes class.
	 *
	 * @package WeCreativez
	 *
	 * @since 1.0.0
	 */
	class ATCP_Shortcodes {

		/**
		 * Init shortcodes.
		 *
		 * @since 1.0.0
		 */
		public function __construct() {

			/**
			 * Display related products within the popup.
			 *
			 * @since 1.0.0
			 * @deprecated 1.0.1 Use [atcp_related_products]
			 */
			add_shortcode( 'atcp_realted_products', array( $this, 'related_products' ) );

			add_shortcode( 'atcp_related_products', array( $this, 'related_products' ) );
			add_shortcode( 'atcp_upsell_products', array( $this, 'upsell_products' ) );
			add_shortcode( 'atcp_cross_sell_products', array( $this, 'cross_sell_products' ) );
		}

		/**
		 * Related products shortcode callback function.
		 *
		 * @since 1.0.0
		 *
		 * @param array $atts   Shortcode parameters.
		 */
		public function related_products( $atts ) {
			$a = shortcode_atts(
				array(
					'limit' => 3,
					'title' => 'Related Products',
				),
				$atts
			);

			$related_products = $this->get_related_product_ids();

			if ( ! $related_products ) {
				return;
			}

			ob_start();
			?>
				<?php if ( $a['title'] ) : ?>
					<h3 style="text-align: center"><?php echo esc_html( $a['title'] ); ?></h3>
				<?php endif; ?>

				<?php
					$this->product_loop(
						array(
							'post__in'       => $related_products,
							'posts_per_page' => $a['limit'],
						)
					);
				?>

			<?php
			return ob_get_clean();
		}

		/**
		 * Upsell products shortcode callback function.
		 *
		 * @since 1.0.0
		 *
		 * @param array $atts   Shortcode parameters.
		 */
		public function upsell_products( $atts ) {
			$a = shortcode_atts(
				array(
					'limit' => 3,
					'title' => 'Upsell Products',
				),
				$atts
			);

			$upsell_products = $this->get_upsell_product_ids();

			if ( ! $upsell_products ) {
				return;
			}

			ob_start();
			?>
				<?php if ( $a['title'] ) : ?>
					<h3 style="text-align: center"><?php echo esc_html( $a['title'] ); ?></h3>
				<?php endif; ?>

				<?php
					$this->product_loop(
						array(
							'post__in'       => $upsell_products,
							'posts_per_page' => $a['limit'],
						)
					);
				?>

			<?php
			return ob_get_clean();
		}

		/**
		 * Cross sell products shortcode callback function.
		 *
		 * @since 1.0.0
		 *
		 * @param array $atts   Shortcode parameters.
		 */
		public function cross_sell_products( $atts ) {
			$a = shortcode_atts(
				array(
					'limit' => 3,
					'title' => 'Cross Sell Products',
				),
				$atts
			);

			$cross_sell_products = $this->get_cross_sell_product_ids();

			if ( ! $cross_sell_products ) {
				return;
			}

			ob_start();
			?>
				<?php if ( $a['title'] ) : ?>
					<h3 style="text-align: center"><?php echo esc_html( $a['title'] ); ?></h3>
				<?php endif; ?>

				<?php
					$this->product_loop(
						array(
							'post__in'       => $cross_sell_products,
							'posts_per_page' => $a['limit'],
						)
					);
				?>

			<?php
			return ob_get_clean();
		}


		/**
		 * Get related products IDs.
		 *
		 * @since 1.0.0
		 *
		 * @return array Related product IDs.
		 */
		protected function get_related_product_ids() {
			$product = $this->get_last_product();

			if ( ! $product ) {
				return false;
			}

			$product_id = -1;

			if ( 0 !== $product->get_parent_id() ) {
				$product_id = $product->get_parent_id();
			} else {
				$product_id = $product->get_id();
			}

			return wc_get_related_products( $product_id, 100 );
		}

		/**
		 * Get upsell products IDs.
		 *
		 * @since 1.0.0
		 *
		 * @return array Upsell product IDs.
		 */
		protected function get_upsell_product_ids() {
			$product = $this->get_last_product();

			if ( ! $product ) {
				return false;
			}

			return $product->get_upsell_ids();
		}

		/**
		 * Get cross sell products IDs.
		 *
		 * @since 1.0.0
		 *
		 * @return array Cross sell product IDs.
		 */
		protected function get_cross_sell_product_ids() {
			$product = $this->get_last_product();

			if ( ! $product ) {
				return false;
			}

			return $product->get_cross_sell_ids();
		}

		/**
		 * Get last added product object.
		 *
		 * @since 1.0.0
		 *
		 * @return object WC_Product
		 */
		protected function get_last_product() {
			// Get last cart item key.
			$cart_item_key = atcp_get_last_added_cart_key();

			if ( ! $cart_item_key ) {
				return false;
			}

			$cart      = WC()->cart->get_cart();
			$cart_item = $cart[ $cart_item_key ];
			$_product  = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );

			return $_product;
		}

		/**
		 * WooCommerce product loop.
		 *
		 * @param  array $args WP_Query args.
		 * @return void
		 */
		protected function product_loop( $args ) {
			$a = wp_parse_args(
				$args,
				array(
					'post_type'      => 'product',
					'posts_per_page' => 3,
				)
			);

			?>
				<div class="wc-atcp-product-grid wc-atcp-product-grid--3">
					<ul class="products">
						<?php
						$loop = new WP_Query( $a );

						if ( $loop->have_posts() ) {
							while ( $loop->have_posts() ) :
								$loop->the_post();
								wc_get_template_part( 'content', 'product' );
								endwhile;
						}

						wp_reset_postdata();
						?>
					</ul>
				</div>
			<?php
		}

	}

	return new ATCP_Shortcodes();
}
